Documentation
¶
Index ¶
- func CreateFileIfMissing(filename string)
- func DownloadRemoteFile(destination, remoteAdress string)
- func EliminateDuplicates(theStrings []string) []string
- func EliminateStringInSlice(theStrings []string, deadString string) []string
- func FailError(err error)
- func FileExists(path string) bool
- func GetFilesInDir(path string) []string
- func GotError(err error) bool
- func PrintStringSlice(theStrigSlice []string, doPrint bool)
- func StringAtIndex(index int, slice []string) string
- func StringInSlice(theSlice []string, item string) bool
- type Download
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateFileIfMissing ¶
func CreateFileIfMissing(filename string)
CreateFileIfMissing creates a file if it does not exist
func DownloadRemoteFile ¶
func DownloadRemoteFile(destination, remoteAdress string)
DownloadRemoteFile downloads a remote file via a remote adress
func EliminateDuplicates ¶
EliminateDuplicates eliminates duplicates in a given slice of strings
func EliminateStringInSlice ¶
EliminateStringInSlice eliminates all duplicates of a specific string
func GetFilesInDir ¶
GetFilesInDir returns names of all files at given path
func PrintStringSlice ¶
PrintStringSlice is a debug funktion to display content of arrays with unknown size
func StringAtIndex ¶
StringAtIndex returns string at index or an empty string if none is found
func StringInSlice ¶
StringInSlice checks if string is element in given slice
Types ¶
Click to show internal directories.
Click to hide internal directories.